@@ -22,7 +22,7 @@ predict.scope.logistic = function(object, newdata, probs = TRUE, include_interce
   p = dim(newdata)[ 2 ]
   factor_ind = rep(F, p)
   for ( j in 1:p ) {
-    if (( class(newdata[ , j ]) != "numeric" ) && ( class(newdata[ , j ]) != "numeric" )) factor_ind[ j ] = T
+    if (!is.numeric(newdata[,j])) fator_ind[j] = T
   }
   xshrink = data.frame(newdata[ , factor_ind, drop = F ])
   if ( include_intercept == FALSE ) {
